from distutils.core import setup

setup(

name='weilanbaizhanMath2',	# 对外我们模块的名字

version='1.0', # 版本号

description='这是第一个对外发布的模块，测试哦',	#描述

author='lanwei', # 作者

author_email='lanwei236@163.com',

py_modules=['weilanbaizhanMath2.demo1','weilanbaizhanMath2.demo2'] # 要发布的模块

)